@@ -389,6 +389,7 @@ KateNavigationConfigTab::KateNavigationConfigTab(QWidget *parent)
     observeChanges(ui->sbAutoCenterCursor);
     observeChanges(ui->chkCamelCursor);
     observeChanges(ui->cmbMultiCursorModifier);
+    observeChanges(ui->cbCycleBookmarks);
 
     layout->addWidget(newWidget);
 }
@@ -440,6 +441,7 @@ void KateNavigationConfigTab::apply()
     KateViewConfig::global()->setValue(KateViewConfig::BackspaceRemoveComposedCharacters, ui->chkBackspaceRemoveComposed->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::PersistentSelection, ui->cbTextSelectionMode->currentIndex() == 1);
     KateViewConfig::global()->setValue(KateViewConfig::ScrollPastEnd, ui->chkScrollPastEnd->isChecked());
+    KateViewConfig::global()->setValue(KateViewConfig::CycleThroughBookmarks, ui->cbCycleBookmarks->isChecked());
 
     const int modifers = ui->cmbMultiCursorModifier->currentData().toInt();
     KateViewConfig::global()->setMultiCursorModifiers(Qt::KeyboardModifiers(modifers));
@@ -459,6 +461,7 @@ void KateNavigationConfigTab::reload()
     ui->chkCamelCursor->setChecked(KateDocumentConfig::global()->camelCursor());
 
     ui->sbAutoCenterCursor->setValue(KateViewConfig::global()->autoCenterLines());
+    ui->cbCycleBookmarks->setChecked(KateViewConfig::global()->value(KateViewConfig::CycleThroughBookmarks).toBool());
 
     const int mods = KateViewConfig::global()->multiCursorModifiers();
     const auto count = ui->cmbMultiCursorModifier->count();
@@ -595,7 +598,7 @@ void KateEditGeneralConfigTab::reload()
     }
     ui->cmbEncloseSelection->setCurrentIndex(ui->cmbEncloseSelection->findText(KateViewConfig::global()->charsToEncloseSelection()));
 
-    const int id = static_cast<int>(KateViewConfig::global()->inputMode());
+    const int id = static_cast<int>(KateViewConfig::global()->value(KateViewConfig::InputMode).toUInt());
     ui->cmbInputMode->setCurrentIndex(ui->cmbInputMode->findData(id));
     ui->chkAccessibility->setChecked(KateViewConfig::global()->value(KateViewConfig::EnableAccessibility).toBool());
 }
@@ -773,13 +776,13 @@ KateViewDefaultsConfig::KateViewDefaultsConfig(QWidget *parent)
         ui->cmbDynamicWordWrapIndicator->setEnabled(cbx->isChecked());
         ui->sbDynamicWordWrapDepth->setEnabled(cbx->isChecked());
     };
-    connect(textareaUi->cbxWordWrap, &QCheckBox::stateChanged, this, a);
+    connect(textareaUi->cbxWordWrap, &QCheckBox::checkStateChanged, this, a);
     a();
     auto b = [cbx = textareaUi->cbxIndentWrappedLines, sb = textareaUi->sbDynamicWordWrapDepth]() {
         sb->setEnabled(cbx->isChecked());
     };
     b();
-    connect(textareaUi->cbxIndentWrappedLines, &QCheckBox::stateChanged, this, b);
+    connect(textareaUi->cbxIndentWrappedLines, &QCheckBox::checkStateChanged, this, b);
     observeChanges(textareaUi->cbxIndentWrappedLines);
     observeChanges(textareaUi->sbDynamicWordWrapDepth);
     observeChanges(textareaUi->sliSetMarkerSize);
@@ -979,7 +982,6 @@ KateSaveConfigTab::KateSaveConfigTab(QWidget *parent)
         i18n("%1 backs up unsaved files to \"swap files.\" Swap files allow %1 to recover your work in the case of a system crash. Disabling swap files may "
              "cause data loss in case of a system crash.",
              QCoreApplication::applicationName()));
-    uiadv->lblExplanatory->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
 
     // "What's This?" help can be found in the ui file
 
@@ -999,6 +1001,7 @@ KateSaveConfigTab::KateSaveConfigTab(QWidget *parent)
     observeChanges(ui->spbAutoSaveInterval);
 
     observeChanges(uiadv->chkAutoReloadVersionControl);
+    observeChanges(uiadv->chkAutoReloadOnExternalChanges);
 
     observeChanges(uiadv->chkBackupLocalFiles);
     observeChanges(uiadv->chkBackupRemoteFiles);
@@ -1009,6 +1012,7 @@ KateSaveConfigTab::KateSaveConfigTab(QWidget *parent)
     observeChanges(uiadv->edtBackupSuffix);
     observeChanges(uiadv->kurlSwapDirectory);
     observeChanges(uiadv->spbSwapFileSync);
+    observeChanges(uiadv->chkEditorConfig);
 
     internalLayout->addWidget(newWidget);
     internalLayout2->addWidget(newWidget2);
@@ -1114,6 +1118,8 @@ void KateSaveConfigTab::apply()
     KateDocumentConfig::global()->setValue(KateDocumentConfig::AutoSaveInteral, ui->spbAutoSaveInterval->value());
 
     KateDocumentConfig::global()->setValue(KateDocumentConfig::AutoReloadIfStateIsInVersionControl, uiadv->chkAutoReloadVersionControl->isChecked());
+    KateDocumentConfig::global()->setValue(KateDocumentConfig::AutoReloadOnExternalChanges, uiadv->chkAutoReloadOnExternalChanges->isChecked());
+    KateDocumentConfig::global()->setValue(KateDocumentConfig::UseEditorConfig, uiadv->chkEditorConfig->isChecked());
 
     KateDocumentConfig::global()->configEnd();
     KateGlobalConfig::global()->configEnd();
@@ -1183,6 +1189,8 @@ void KateSaveConfigTab::reload()
     ui->spbAutoSaveInterval->setValue(KateDocumentConfig::global()->autoSaveInterval());
 
     uiadv->chkAutoReloadVersionControl->setChecked(KateDocumentConfig::global()->value(KateDocumentConfig::AutoReloadIfStateIsInVersionControl).toBool());
+    uiadv->chkAutoReloadOnExternalChanges->setChecked(KateDocumentConfig::global()->value(KateDocumentConfig::AutoReloadOnExternalChanges).toBool());
+    uiadv->chkEditorConfig->setChecked(KateDocumentConfig::global()->value(KateDocumentConfig::UseEditorConfig).toBool());
 }
 
 void KateSaveConfigTab::reset()
